.background-theme[data-v-46d7eca7]{background-repeat:no-repeat;background-size:cover;background-position:center}.sidebar[data-v-46d7eca7]{position:absolute;top:48px;bottom:0;left:-15rem;width:15rem;padding:12px;display:flex;flex-direction:column;align-items:flex-start;gap:2rem;background:rgb(255,255,255);box-shadow:4px 8px 4px #00000005;box-sizing:border-box;z-index:2;transition:.6s}.sidebar.open[data-v-46d7eca7]{left:0}.sidebar .sidebar-content[data-v-46d7eca7]{display:flex;flex-direction:column;overflow:auto;width:100%}.sidebar .sidebar-content .item[data-v-46d7eca7]{min-height:unset;cursor:pointer;padding:1rem;box-sizing:border-box;display:flex;gap:1rem;align-items:center;justify-content:flex-start;border-radius:4px}.sidebar .sidebar-content .item .item-title[data-v-46d7eca7]{font-family:var(--font-family);font-style:normal;font-weight:500;font-size:14px;user-select:none;line-height:20px;letter-spacing:.1px;color:#49454f}.sidebar .sidebar-content .item[data-v-46d7eca7]:hover{background:rgba(0,0,0,.062745098)}.sidebar .sidebar-content .item[data-v-46d7eca7]:active{background:rgba(0,0,0,.1254901961)}.sidebar .sidebar-content .item:active .item-title[data-v-46d7eca7]{color:var(--color-main)}.sidebar .sidebar-content .item.disabled[data-v-46d7eca7]{opacity:.8;pointer-events:none}.sidebar .sidebar-content .active[data-v-46d7eca7]{background:rgba(0,0,0,.1254901961);cursor:default}.sidebar .sidebar-content .active .item-title[data-v-46d7eca7]{color:var(--color-main)}.background-theme[data-v-d8d35227]{background-repeat:no-repeat;background-size:cover;background-position:center}.navbar[data-v-d8d35227]{display:flex;justify-content:space-between;align-items:center;box-shadow:0 0 100px #0000001a;height:48px;padding:0 16px;width:100%;box-sizing:border-box;z-index:2}.navbar.background[data-v-d8d35227]{background:rgba(255,255,255,.8)}.left-side[data-v-d8d35227]{display:flex;flex-direction:row;align-items:center;gap:20px;overflow:hidden}.logo-image[data-v-d8d35227]{max-height:30px;object-fit:contain}.brand[data-v-d8d35227]{display:flex;flex-direction:row;align-items:center;justify-content:center;gap:10px;overflow:hidden}.brand .brand-name[data-v-d8d35227]{color:#49454f;font-weight:400;font-size:16px;line-height:24px}.right-side[data-v-d8d35227]{display:flex;gap:20px;align-items:center}.signed-email[data-v-d8d35227]{display:flex;align-items:center;font-size:14px;line-height:20px;color:#49454f}.sidebar-menu-icon[data-v-d8d35227]{cursor:pointer;width:24px;height:24px;flex-shrink:0;border-radius:8px}@media screen and (min-width: 1200px){.sidebar-menu-icon.dash[data-v-d8d35227]:not(.desktop){display:none}}.sidebar-menu-icon.dash.mobile[data-v-d8d35227]{display:unset}
