import{_ as n,C as p}from"./View.vue_vue_type_script_setup_true_lang.acd841ee.js";import{d as i,ea as s,o as a,c as m,u as d}from"./vue-router.e3ef87f0.js";import"./gateway.e3730daa.js";import"./popupNotifcation.bf248d47.js";import"./fetch.1531f1e4.js";import"./record.9f354c97.js";import"./SaveButton.e9805d23.js";import"./UnsavedChangesHandler.0b7e2325.js";import"./ExclamationCircleOutlined.5cb43a6c.js";import"./CrudView.6dee12dd.js";import"./router.7553e78c.js";import"./DocsButton.vue_vue_type_script_setup_true_lang.7e26700d.js";import"./BookOutlined.2206ef88.js";import"./url.d7fc9f74.js";import"./PhDotsThreeVertical.vue.4a059a70.js";import"./Badge.e09547ac.js";import"./index.45410f8d.js";import"./asyncComputed.e840076d.js";import"./polling.9969b38e.js";import"./PhPencil.vue.c5b74fb4.js";import"./index.38be2fa1.js";(function(){try{var o=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},r=new Error().stack;r&&(o._sentryDebugIds=o._sentryDebugIds||{},o._sentryDebugIds[r]="4b07da66-46ca-4222-853a-158dbe6c6340",o._sentryDebugIdIdentifier="sentry-dbid-4b07da66-46ca-4222-853a-158dbe6c6340")}catch{}})();const z=i({__name:"EnvVars",setup(o){const e=s().params.projectId,t=new p(e);return(c,u)=>(a(),m(n,{"env-var-repository":d(t),mode:"console"},null,8,["env-var-repository"]))}});export{z as default};
//# sourceMappingURL=EnvVars.d3d83eff.js.map
