.tree[data-v-af388efb] .ant-tree-node-content-wrapper{user-select:auto}.terminal[data-v-1edcaf0f]{margin-top:20px;width:96%;background-color:#212427;padding:12px 16px;border-radius:8px;overflow:scroll}.log-text[data-v-1edcaf0f]{color:#fff;margin:4px}.panel[data-v-c99a5995] .ant-collapse-header{padding:0}[data-v-8a35b2bd]:root{--main-font-family: DM Sans, sans-serif}[data-v-8a35b2bd]:root{--abstra-main-color-dark: #343b46}.p-dropdown[data-v-8a35b2bd]{border-radius:8px;border:1px solid #343b46;background-color:#fff;height:37px;padding:0 10px;align-items:center}.p-dropdown-panel[data-v-8a35b2bd]{background-color:#fff;padding:10px}.stage-column[data-v-8a35b2bd]{background-color:#e9eaeb;border-radius:6px;padding:8px;height:fit-content;width:300px}.tag[data-v-8a35b2bd]{max-width:250px}.skeleton[data-v-8a35b2bd] .ant-skeleton-button{height:200px}.draggable-handler[data-v-8a35b2bd]{cursor:grab}[data-v-f5bf528d]:root{--main-font-family: DM Sans, sans-serif}[data-v-f5bf528d]:root{--abstra-main-color-dark: #343b46}.p-dropdown[data-v-f5bf528d]{border-radius:8px;border:1px solid #343b46;background-color:#fff;height:37px;padding:0 10px;align-items:center}.p-dropdown-panel[data-v-f5bf528d]{background-color:#fff;padding:10px}.tag[data-v-f5bf528d]{background-color:#e9eaeb;cursor:pointer;max-width:275px}[data-v-776f7f6d]:root{--main-font-family: DM Sans, sans-serif}[data-v-776f7f6d]:root{--abstra-main-color-dark: #343b46}.p-dropdown[data-v-776f7f6d]{border-radius:8px;border:1px solid #343b46;background-color:#fff;height:37px;padding:0 10px;align-items:center}.p-dropdown-panel[data-v-776f7f6d]{background-color:#fff;padding:10px}.stages-container[data-v-776f7f6d]{max-width:100vw;position:relative;flex-grow:1;display:flex}.stages-container .stages-content[data-v-776f7f6d]{overflow:auto}.stages-container .stages-content[data-v-776f7f6d] .ant-select-selection-item{display:flex;align-items:center}.stages-container .stages-content .draggable[data-v-776f7f6d]{display:flex;gap:8px;overflow:hidden}.ghost[data-v-776f7f6d]{opacity:.5;background-color:#8692a5}.workflow-container[data-v-765d5d38]{height:100%;width:100%;position:relative}
