import{n as t,a as s}from"./string.5524ff61.js";import"./vue-router.e3ef87f0.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},a=new Error().stack;a&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[a]="af7b0797-da61-44c1-8899-0125c45cdf28",e._sentryDebugIdIdentifier="sentry-dbid-af7b0797-da61-44c1-8899-0125c45cdf28")}catch{}})();const o=["False","None","True","and","as","assert","async","await","break","class","continue","def","del","elif","else","except","finally","for","from","global","if","import","in","is","lambda","nonlocal","not","or","pass","raise","return","try","while","with","yield"];function l(e){return e.replace(/\.py$/,"").trim().length===0?{valid:!1,reason:"File name cannot be empty"}:e.length>255?{valid:!1,reason:"File name cannot be longer than 255 characters"}:e.endsWith(".py")?{valid:!0}:{valid:!1,reason:"File name must end with .py"}}function m(e){if(!l(e).valid)throw new Error("Invalid filename");const a=e.slice(0,-3);return t(a,!0,!0,!0,!0)+".py"}function b(e){return t(e,!0,!0,!0,!0)+".py"}function d(e){return e.trim().length===0?{valid:!1,reason:"Variable name cannot be empty"}:/^[a-zA-Z_]/.test(e)?o.includes(e)?{valid:!1,reason:"Variable name cannot be a Python keyword"}:{valid:!0}:{valid:!1,reason:"Variable name must start with a letter or underscore"}}function p(e){const a=d(e);if(!a.valid)throw new Error(a.reason);return e.split(".").map(i=>t(i,!1,!0,!1)).join(".")}function f(e){return e.trim().length===0?{valid:!1,reason:"Path cannot be empty"}:{valid:!0}}function y(e){if(!f(e).valid)throw new Error("Invalid path");return e.split("/").filter(Boolean).map(r=>s(r)).join("/")}export{d as a,b,f as c,y as d,m as e,p as n,l as v};
//# sourceMappingURL=validations.494fd4a4.js.map
