import{L as t}from"./Logo.19ebe967.js";import{d as a,o as n,c as r,u as f}from"./vue-router.e3ef87f0.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},o=new Error().stack;o&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[o]="5f6554ba-ee98-49cb-98ab-1f0ff8905171",e._sentryDebugIdIdentifier="sentry-dbid-5f6554ba-ee98-49cb-98ab-1f0ff8905171")}catch{}})();const d="/assets/logo.0faadfa2.svg",u=a({__name:"AbstraLogo",props:{hideText:{type:Boolean},size:{}},setup(e){return(o,s)=>(n(),r(t,{"image-url":f(d),"brand-name":"Abstra","hide-text":o.hideText,size:o.size},null,8,["image-url","hide-text","size"]))}});export{u as _};
//# sourceMappingURL=AbstraLogo.vue_vue_type_script_setup_true_lang.d1e74e3b.js.map
