import{_}from"./Login.vue_vue_type_script_setup_true_lang.56434cb6.js";import{b as f,u as m}from"./workspaceStore.ba59e8f0.js";import{d as l,eo as b,ea as y,o as g,X as w,b as k,u,$ as h}from"./vue-router.e3ef87f0.js";import"./Logo.19ebe967.js";import"./string.5524ff61.js";import"./CircularLoading.046b2d5c.js";import"./index.0d9beae4.js";import"./index.38be2fa1.js";import"./url.d7fc9f74.js";import"./colorHelpers.68e96910.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},o=new Error().stack;o&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[o]="7f03fdc5-35ad-47e3-aa26-b6db9e164e42",e._sentryDebugIdIdentifier="sentry-dbid-7f03fdc5-35ad-47e3-aa26-b6db9e164e42")}catch{}})();const v={class:"runner"},I=l({__name:"Login",setup(e){const o=b(),r=y(),i=f(),a=m(),p=async()=>{await i.signUp();const{redirect:t,...s}=r.query;if(t){await o.push({path:t,query:s,params:r.params});return}o.push({name:"playerHome",query:s})};return(t,s)=>{var n,d,c;return g(),w("div",v,[k(_,{"logo-url":(d=(n=u(a).state.workspace)==null?void 0:n.logoUrl)!=null?d:void 0,"brand-name":(c=u(a).state.workspace)==null?void 0:c.brandName,onDone:p},null,8,["logo-url","brand-name"])])}}});const $=h(I,[["__scopeId","data-v-fc57ade6"]]);export{$ as default};
//# sourceMappingURL=Login.53e8856d.js.map
