import{eM as t,eN as r}from"./vue-router.e3ef87f0.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},n=new Error().stack;n&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[n]="842d3ece-beea-4c3a-9e58-2bd5f606a501",e._sentryDebugIdIdentifier="sentry-dbid-842d3ece-beea-4c3a-9e58-2bd5f606a501")}catch{}})();function o(e,n){return t(1,arguments),r(e,Date.now(),n)}export{o as f};
//# sourceMappingURL=index.738a9a5d.js.map
