import{B as d}from"./BookOutlined.2206ef88.js";import{d as f,o as s,c as l,w as o,b as c,u as n,Z as u,X as i,aF as p,aR as b,bP as y}from"./vue-router.e3ef87f0.js";(function(){try{var t=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},e=new Error().stack;e&&(t._sentryDebugIds=t._sentryDebugIds||{},t._sentryDebugIds[e]="72be9676-f962-45f0-ad14-182b62666a7a",t._sentryDebugIdIdentifier="sentry-dbid-72be9676-f962-45f0-ad14-182b62666a7a")}catch{}})();const g=f({__name:"DocsButton",props:{path:{}},setup(t){return(e,r)=>{var a;return s(),l(n(y),{class:"docs-button",href:`https://docs.abstra.io/${(a=e.path)!=null?a:""}`,target:"_blank",type:"text",size:"small"},{icon:o(()=>[c(n(d))]),default:o(()=>[e.$slots.default?u(e.$slots,"default",{key:0}):(s(),i(b,{key:1},[p("Docs")],64))]),_:3},8,["href"])}}});export{g as _};
//# sourceMappingURL=DocsButton.vue_vue_type_script_setup_true_lang.7e26700d.js.map
