import{E as y}from"./api.240e21a9.js";import{C as w}from"./ContentLayout.9508ac8e.js";import{d as c,L as g,N as f,e as _,o as e,c as i,w as d,b as n,u as o,R as s}from"./vue-router.e3ef87f0.js";import{K as v,_ as K,W as R,E,a as T}from"./WorkflowView.edbfd154.js";import{A as p,T as V}from"./TabPane.16834058.js";import"./fetch.1531f1e4.js";import"./metadata.0aaab781.js";import"./PhBug.vue.5783ebba.js";import"./PhCheckCircle.vue.e0058912.js";import"./PhKanban.vue.97825602.js";import"./PhWebhooksLogo.vue.259f6aaf.js";import"./polling.9969b38e.js";import"./asyncComputed.e840076d.js";import"./PhQuestion.vue.bb633fb3.js";import"./ant-design.ab86670b.js";import"./index.45410f8d.js";import"./index.738a9a5d.js";import"./index.2150a909.js";import"./CollapsePanel.b237cad2.js";import"./index.cd9b2c78.js";import"./index.8b67a975.js";import"./Badge.e09547ac.js";import"./PhArrowCounterClockwise.vue.b57d3f96.js";import"./Workflow.f292df08.js";import"./validations.494fd4a4.js";import"./string.5524ff61.js";import"./uuid.94c3ff7b.js";import"./index.0d9beae4.js";import"./workspaces.3503b70f.js";import"./workspaceStore.ba59e8f0.js";import"./url.d7fc9f74.js";import"./colorHelpers.68e96910.js";import"./record.9f354c97.js";import"./index.60f1e584.js";import"./PhArrowDown.vue.a29a48a3.js";import"./Card.9e74c9cd.js";import"./LoadingOutlined.e83670fa.js";import"./DeleteOutlined.b3749286.js";import"./PhDownloadSimple.vue.c60d2774.js";import"./utils.2789cdf5.js";import"./LoadingContainer.e164c4c5.js";(function(){try{var r=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},t=new Error().stack;t&&(r._sentryDebugIds=r._sentryDebugIds||{},r._sentryDebugIds[t]="915567ae-75a0-455d-9f51-1f8dd60c0695",r._sentryDebugIdIdentifier="sentry-dbid-915567ae-75a0-455d-9f51-1f8dd60c0695")}catch{}})();const yo=c({__name:"WorkflowThreads",setup(r){const t=new E,m=new T,b=new g(f.array(f.string()),"kanban-selected-stages"),u=new y,a=_("kanban");return(W,l)=>(e(),i(w,{"full-width":""},{default:d(()=>[n(o(V),{activeKey:a.value,"onUpdate:activeKey":l[0]||(l[0]=k=>a.value=k)},{default:d(()=>[n(o(p),{key:"kanban",tab:"Kanban View"}),n(o(p),{key:"table",tab:"Table View"}),n(o(p),{key:"workflow",tab:"Workflow View"})]),_:1},8,["activeKey"]),a.value==="kanban"?(e(),i(v,{key:0,"kanban-repository":o(t),"kanban-stages-storage":o(b),"stage-run-repository":o(m)},null,8,["kanban-repository","kanban-stages-storage","stage-run-repository"])):s("",!0),a.value==="table"?(e(),i(K,{key:1,"kanban-repository":o(t)},null,8,["kanban-repository"])):s("",!0),a.value==="workflow"?(e(),i(R,{key:2,"kanban-repository":o(t),"workflow-api":o(u)},null,8,["kanban-repository","workflow-api"])):s("",!0)]),_:1}))}});export{yo as default};
//# sourceMappingURL=WorkflowThreads.0f5d12f0.js.map
