import"./vue-router.e3ef87f0.js";(function(){try{var x=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},d=new Error().stack;d&&(x._sentryDebugIds=x._sentryDebugIds||{},x._sentryDebugIds[d]="83f23dc8-b183-40dd-adc0-2a1a4bda81cc",x._sentryDebugIdIdentifier="sentry-dbid-83f23dc8-b183-40dd-adc0-2a1a4bda81cc")}catch{}})();const t=()=>"xxxxxxxx-xxxx-4xxx-yxxx-xxxxxxxxxxxx".replace(/[xy]/g,function(x){const d=Math.random()*16|0;return(x=="x"?d:d&3|8).toString(16)});export{t as u};
//# sourceMappingURL=uuid.94c3ff7b.js.map
