import{$ as t,r as c,o as s,c as a}from"./vue-router.e3ef87f0.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},o=new Error().stack;o&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[o]="c33abda9-df89-48f7-afcd-ff98f37ee1aa",e._sentryDebugIdIdentifier="sentry-dbid-c33abda9-df89-48f7-afcd-ff98f37ee1aa")}catch{}})();const d={};function f(e,o){const n=c("RouterView");return s(),a(n,{class:"router"})}const _=t(d,[["render",f],["__scopeId","data-v-3c2b9654"]]);export{_ as default};
//# sourceMappingURL=Home.f0919da3.js.map
