import{B as n,R as t}from"./Badge.e09547ac.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},d=new Error().stack;d&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[d]="fb25a70c-0699-43a3-b00d-b287f38eaeda",e._sentryDebugIdIdentifier="sentry-dbid-fb25a70c-0699-43a3-b00d-b287f38eaeda")}catch{}})();n.install=function(e){return e.component(n.name,n),e.component(t.name,t),e};
//# sourceMappingURL=index.60f1e584.js.map
