import{k as a,T as n,m as r,P as o,C as d,M as c,s as p,n as s,p as f,q as m,t as u,v as b}from"./vue-router.e3ef87f0.js";import{s as g,c as y,a as i}from"./workspaceStore.ba59e8f0.js";import{_ as l}from"./App.vue_vue_type_style_index_0_lang.b2ec52b5.js";import"./url.d7fc9f74.js";import"./colorHelpers.68e96910.js";import"./PlayerConfigProvider.d7d0bb7a.js";import"./index.0d9beae4.js";(function(){try{var t=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},e=new Error().stack;e&&(t._sentryDebugIds=t._sentryDebugIds||{},t._sentryDebugIds[e]="8bbdb0ba-c3ce-4df6-8077-2195a0340ec9",t._sentryDebugIdIdentifier="sentry-dbid-8bbdb0ba-c3ce-4df6-8077-2195a0340ec9")}catch{}})();class w{static init(){setInterval(()=>fetch("/_version"),20*1e3)}}(async()=>{await g();const t=y(),e=a({render:()=>f(l)});n.init(),r(e,i),w.init(),e.use(i),e.use(t),e.use(o),e.mount("#app"),e.component("VSelect",d),e.component("Markdown",c),e.component("Message",p),s(e,m),s(e,u),s(e,b)})();
//# sourceMappingURL=player.a6b83807.js.map
