import{O as r}from"./workspaceStore.ba59e8f0.js";import{d as i,W as l,o as c,X as u,b as a,w as n,u as d,aF as o,d9 as f,d8 as _}from"./vue-router.e3ef87f0.js";import"./url.d7fc9f74.js";import"./colorHelpers.68e96910.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},t=new Error().stack;t&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[t]="f9e57d47-0595-4c9f-a967-af95d4d073cd",e._sentryDebugIdIdentifier="sentry-dbid-f9e57d47-0595-4c9f-a967-af95d4d073cd")}catch{}})();const b=i({__name:"OidcLoginCallback",setup(e){return l(async()=>{await new r().loginCallback()}),(t,s)=>(c(),u("div",null,[a(d(f),null,{default:n(()=>[o("You're authenticated")]),_:1}),a(d(_),null,{default:n(()=>[o(" This window should close automatically. Please close it manually if it doesn't. ")]),_:1})]))}});export{b as default};
//# sourceMappingURL=OidcLoginCallback.017f8637.js.map
