import{O as r}from"./workspaceStore.ba59e8f0.js";import{d as l,W as i,o as c,X as u,b as a,w as o,u as d,aF as n,d9 as f,d8 as b}from"./vue-router.e3ef87f0.js";import"./url.d7fc9f74.js";import"./colorHelpers.68e96910.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},t=new Error().stack;t&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[t]="20ccb15d-ba14-44d0-b8e1-d5cea46e9d6e",e._sentryDebugIdIdentifier="sentry-dbid-20ccb15d-ba14-44d0-b8e1-d5cea46e9d6e")}catch{}})();const w=l({__name:"OidcLogoutCallback",setup(e){return i(async()=>{await new r().logoutCallback()}),(t,s)=>(c(),u("div",null,[a(d(f),null,{default:o(()=>[n("You're authenticated")]),_:1}),a(d(b),null,{default:o(()=>[n(" This window should close automatically. Please close it manually if it doesn't. ")]),_:1})]))}});export{w as default};
//# sourceMappingURL=OidcLogoutCallback.1071b629.js.map
