[data-v-048030b3]:root{--main-font-family: DM Sans, sans-serif}[data-v-048030b3]:root{--abstra-main-color-dark: #343b46}.p-dropdown[data-v-048030b3]{border-radius:8px;border:1px solid #343b46;background-color:#fff;height:37px;padding:0 10px;align-items:center}.p-dropdown-panel[data-v-048030b3]{background-color:#fff;padding:10px}.files[data-v-048030b3]{margin-top:20px}.file-size[data-v-048030b3]{color:#8692a5}
