import{d as i,eh as l,f as d,o as t,X as a,R as r,e9 as _,$ as g}from"./vue-router.e3ef87f0.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},o=new Error().stack;o&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[o]="c033455d-0360-4c55-a30d-f858a4eafb34",e._sentryDebugIdIdentifier="sentry-dbid-c033455d-0360-4c55-a30d-f858a4eafb34")}catch{}})();const p={class:"logo"},u=["src","alt"],f={key:1},m=i({__name:"Logo",props:{imageUrl:{},brandName:{},hideText:{type:Boolean},size:{}},setup(e){const o=e;l(s=>({"4352941e":n.value}));const n=d(()=>o.size==="large"?"80px":"50px"),c=d(()=>`${o.brandName} Logo`);return(s,y)=>(t(),a("div",p,[s.imageUrl?(t(),a("img",{key:0,class:"logo-img",src:s.imageUrl,alt:c.value},null,8,u)):r("",!0),s.hideText?r("",!0):(t(),a("span",f,_(s.brandName),1))]))}});const h=g(m,[["__scopeId","data-v-16688d14"]]);export{h as L};
//# sourceMappingURL=Logo.19ebe967.js.map
