import{d as i,o as p,c as n,w as m,b as a,u as e}from"./vue-router.e3ef87f0.js";import"./editor.a99f287e.js";import{W as s}from"./workspaces.3503b70f.js";import{C as d}from"./ContentLayout.9508ac8e.js";import{_ as f,E as c}from"./View.vue_vue_type_script_setup_true_lang.acd841ee.js";import"./workspaceStore.ba59e8f0.js";import"./url.d7fc9f74.js";import"./colorHelpers.68e96910.js";import"./asyncComputed.e840076d.js";import"./record.9f354c97.js";import"./gateway.e3730daa.js";import"./popupNotifcation.bf248d47.js";import"./fetch.1531f1e4.js";import"./SaveButton.e9805d23.js";import"./UnsavedChangesHandler.0b7e2325.js";import"./ExclamationCircleOutlined.5cb43a6c.js";import"./CrudView.6dee12dd.js";import"./router.7553e78c.js";import"./DocsButton.vue_vue_type_script_setup_true_lang.7e26700d.js";import"./BookOutlined.2206ef88.js";import"./PhDotsThreeVertical.vue.4a059a70.js";import"./Badge.e09547ac.js";import"./index.45410f8d.js";import"./polling.9969b38e.js";import"./PhPencil.vue.c5b74fb4.js";import"./index.38be2fa1.js";(function(){try{var o=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},r=new Error().stack;r&&(o._sentryDebugIds=o._sentryDebugIds||{},o._sentryDebugIds[r]="df350a50-5986-453e-93de-edba307cf710",o._sentryDebugIdIdentifier="sentry-dbid-df350a50-5986-453e-93de-edba307cf710")}catch{}})();const F=i({__name:"EnvVarsEditor",setup(o){const r=new c;return(t,u)=>(p(),n(d,null,{default:m(()=>[a(f,{"env-var-repository":e(r),mode:"editor","file-opener":e(s)},null,8,["env-var-repository","file-opener"])]),_:1}))}});export{F as default};
//# sourceMappingURL=EnvVarsEditor.446dd1e8.js.map
