import{P as m}from"./PlayerNavbar.1cc1ef6b.js";import{u as f,i as g}from"./workspaceStore.ba59e8f0.js";import{d as h,eo as y,ea as c,e as b,f as v,r as k,o as i,X as w,u as n,c as L,R as I,a as N,b as C,$ as R}from"./vue-router.e3ef87f0.js";import"./metadata.0aaab781.js";import"./PhBug.vue.5783ebba.js";import"./PhCheckCircle.vue.e0058912.js";import"./PhKanban.vue.97825602.js";import"./PhWebhooksLogo.vue.259f6aaf.js";import"./LoadingOutlined.e83670fa.js";import"./PhSignOut.vue.4fb59e20.js";import"./index.6f617d93.js";import"./Avatar.715e2ca3.js";import"./url.d7fc9f74.js";import"./colorHelpers.68e96910.js";(function(){try{var a=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},e=new Error().stack;e&&(a._sentryDebugIds=a._sentryDebugIds||{},a._sentryDebugIds[e]="cb04daad-d168-4c2f-97db-7aaa9d2a78b3",a._sentryDebugIdIdentifier="sentry-dbid-cb04daad-d168-4c2f-97db-7aaa9d2a78b3")}catch{}})();const V={class:"main-container"},x={class:"content"},B=h({__name:"Main",setup(a){const e=y(),t=f(),d=c().path,o=b(null),u=async({path:r,id:s})=>{o.value=s,await e.push({path:`/${r}`}),o.value=null},p=()=>{e.push({name:"playerLogin"})},l=v(()=>!!c().meta.hideLogin);return g(()=>e.push({name:"playerLogin"})),(r,s)=>{const _=k("RouterView");return i(),w("div",V,[n(t).state.workspace?(i(),L(m,{key:0,"current-path":n(d),"hide-login":l.value,"runner-data":n(t).state.workspace,loading:o.value,onNavigate:u,onLoginClick:p},null,8,["current-path","hide-login","runner-data","loading"])):I("",!0),N("section",x,[C(_)])])}}});const H=R(B,[["__scopeId","data-v-09fccc95"]]);export{H as default};
//# sourceMappingURL=Main.e95134c7.js.map
