import{d as h,eo as A,r as B,u as e,o as s,c as i,bx as C,X as f,b as a,w as t,aF as r,bP as d,a as m,d8 as w,e9 as _,cK as N,ej as I,eb as L,f0 as R,aR as g,R as D,Z as z,$ as S}from"./vue-router.e3ef87f0.js";import{a as $}from"./asyncComputed.e840076d.js";import{G as V}from"./PhChats.vue.e1264b9f.js";import{F}from"./PhSignOut.vue.4fb59e20.js";import{C as P}from"./router.7553e78c.js";import{a as k}from"./gateway.e3730daa.js";import{A as T}from"./index.45410f8d.js";import{A as j}from"./Avatar.715e2ca3.js";import{B as E,A as q,b as G}from"./index.74f6e7f5.js";import{B as H}from"./BookOutlined.2206ef88.js";(function(){try{var n=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},o=new Error().stack;o&&(n._sentryDebugIds=n._sentryDebugIds||{},n._sentryDebugIds[o]="7cb979f6-ae68-4ac9-8d2d-14a6a21c6f57",n._sentryDebugIdIdentifier="sentry-dbid-7cb979f6-ae68-4ac9-8d2d-14a6a21c6f57")}catch{}})();const K={key:1,style:{display:"flex","align-items":"center",gap:"16px"}},M={style:{display:"flex","flex-direction":"column",gap:"10px"}},O={style:{display:"flex",gap:"5px"}},U=h({__name:"LoginBlock",setup(n){function o(b){const y=b.split("@")[0];return I.exports.kebabCase(y).toUpperCase().split("-").slice(0,2).map(p=>p[0]).join("")}const c=A(),{result:l,loading:u,refetch:x}=$(async()=>k.getAuthor());function v(){k.removeAuthor(),P.shutdown(),x(),c.push({name:"login"})}return(b,y)=>{const p=B("RouterLink");return e(u)?(s(),i(e(C),{key:0})):e(l)?(s(),f("div",K,[a(e(d),{class:"intercom-launcher",target:"_blank",type:"link",size:"small",style:{color:"#d14056",display:"flex","align-items":"center",gap:"6px"}},{icon:t(()=>[a(e(V),{size:18})]),default:t(()=>[r(" Support ")]),_:1}),a(e(N),{placement:"bottomRight"},{content:t(()=>[m("div",M,[a(e(w),{size:"small",type:"secondary"},{default:t(()=>[r(_(e(l).claims.email),1)]),_:1}),a(e(d),{type:"text",onClick:v},{default:t(()=>[m("div",O,[a(e(F),{size:"20"}),r(" Logout ")])]),_:1})])]),default:t(()=>[a(e(T),{align:"center",style:{cursor:"pointer"}},{default:t(()=>[a(e(j),{shape:"square"},{default:t(()=>[r(_(o(e(l).claims.email)),1)]),_:1})]),_:1})]),_:1})])):(s(),i(e(d),{key:2},{default:t(()=>[a(p,{to:"/login"},{default:t(()=>[r("Login")]),_:1})]),_:1}))}}}),X={class:"extra"},Z=h({__name:"Navbar",props:{breadcrumb:{}},setup(n){return(o,c)=>(s(),i(e(G),{style:{padding:"5px 25px",border:"1px solid #f0f0f0"}},{subTitle:t(()=>[o.breadcrumb?(s(),i(e(E),{key:0},{default:t(()=>[(s(!0),f(g,null,L(o.breadcrumb,(l,u)=>(s(),i(e(q),{key:u},{default:t(()=>[a(e(R),{to:l.path},{default:t(()=>[r(_(l.label),1)]),_:2},1032,["to"])]),_:2},1024))),128))]),_:1})):D("",!0)]),extra:t(()=>[m("div",X,[a(e(d),{class:"docs-button",href:"https://docs.abstra.io/",target:"_blank",type:"link",style:{color:"#d14056"},size:"small"},{icon:t(()=>[a(e(H))]),default:t(()=>[o.$slots.default?z(o.$slots,"default",{key:0},void 0,!0):(s(),f(g,{key:1},[r("Docs")],64))]),_:3}),a(U)])]),_:3}))}});const ne=S(Z,[["__scopeId","data-v-5ef7b378"]]);export{ne as N};
//# sourceMappingURL=Navbar.e82054e6.js.map
